from __future__ import annotations

from datetime import datetime
from typing import TYPE_CHECKING, List, Optional, Union, Any

if TYPE_CHECKING:
    from ..client import SyncPhraseTMSClient

from ..models import (
    FileNamingSettingsDto,
    EditQASettingsDtoV2,
    FileImportSettingsDto,
    AsyncRequestWrapperV2Dto,
    EditProjectSecuritySettingsDtoV2,
    AddTargetLangDto,
    LqaSettingsDto,
    UpdateCustomFieldInstancesDto,
    AbstractProjectDtoV2,
    CloneProjectDto,
    FinancialSettingsDto,
    PageDtoProviderReference,
    PageDtoTermBaseDto,
    EditProjectV3Dto,
    MTSettingsPerLanguageListDto,
    CreateProjectV3Dto,
    AnalyseSettingsDto,
    PageDtoCustomFieldInstanceDto,
    CustomFieldInstanceDto,
    CreateCustomFieldInstancesDto,
    CreateProjectFromTemplateV2Dto,
    QASettingsDtoV2,
    SearchResponseListTmDto,
    EditProjectMTSettingsDto,
    SetProjectTransMemoriesV3Dto,
    PageDtoAnalyseReference,
    AssignVendorDto,
    PatchProjectDto,
    ProjectTransMemoryListDtoV3,
    AbstractProjectDto,
    AssignableTemplatesDto,
    PageDtoQuoteDto,
    SetFinancialSettingsDto,
    SearchTMRequestDto,
    ProjectWorkflowStepListDtoV2,
    SetProjectStatusDto,
    PageDtoTransMemoryDto,
    AddWorkflowStepsDto,
    JobPartReferences,
    CreateProjectFromTemplateAsyncV2Dto,
    PreTranslateSettingsV4Dto,
    JobPartsDto,
    EnabledQualityChecksDto,
    FileImportSettingsCreateDto,
    EditProjectV2Dto,
    SetTermBaseDto,
    EditProjectMTSettPerLangListDto,
    PageDtoAbstractProjectDto,
    ProviderListDtoV2,
    ProjectTermBaseListDto,
    ProjectSecuritySettingsDtoV2,
    PageDtoProjectReference,
    CustomFieldInstancesDto,
    UpdateCustomFieldInstanceDto, AdminProjectManagerV2

)


class ProjectOperations:
    def __init__(self, client: SyncPhraseTMSClient):
        self.client = client


    def add_target_language_to_project(
        self,
        add_target_lang_dto: AddTargetLangDto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: addTargetLanguageToProject
        Add target languages
        Add target languages to project
        :param add_target_lang_dto: AddTargetLangDto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/projects/{project_uid}/targetLangs"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = add_target_lang_dto

        r = self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    def add_workflow_steps(
        self,
        add_workflow_steps_dto: AddWorkflowStepsDto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: addWorkflowSteps
        Add workflow steps
        
        :param add_workflow_steps_dto: AddWorkflowStepsDto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/projects/{project_uid}/workflowSteps"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = add_workflow_steps_dto

        r = self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    def assign_linguists_from_template(
        self,
        project_uid: str,
        template_uid: str,
        phrase_token: Optional[str] = None,
) -> JobPartsDto:
        """
        Operation id: assignLinguistsFromTemplate
        Assigns providers from template
        
        :param project_uid: str (required), path. 
        :param template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: JobPartsDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/applyTemplate/{template_uid}/assignProviders"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return JobPartsDto(**r.json())
        


    def assign_linguists_from_template_to_job_parts(
        self,
        job_part_references: JobPartReferences,
        project_uid: str,
        template_uid: str,
        phrase_token: Optional[str] = None,
) -> JobPartsDto:
        """
        Operation id: assignLinguistsFromTemplateToJobParts
        Assigns providers from template (specific jobs)
        
        :param job_part_references: JobPartReferences (required), body. 
        :param project_uid: str (required), path. 
        :param template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: JobPartsDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/applyTemplate/{template_uid}/assignProviders/forJobParts"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = job_part_references

        r = self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return JobPartsDto(**r.json())
        


    def assign_vendor_to_project(
        self,
        assign_vendor_dto: AssignVendorDto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: assignVendorToProject
        Assign vendor
        
To unassign Vendor from Project, use empty body:
```
{}
```
    
        :param assign_vendor_dto: AssignVendorDto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/projects/{project_uid}/assignVendor"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = assign_vendor_dto

        r = self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    def assignable_templates(
        self,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> AssignableTemplatesDto:
        """
        Operation id: assignableTemplates
        List assignable templates
        
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AssignableTemplatesDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/assignableTemplates"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AssignableTemplatesDto(**r.json())
        


    def clone_project(
        self,
        clone_project_dto: CloneProjectDto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> AbstractProjectDto:
        """
        Operation id: cloneProject
        Clone project
        
        :param clone_project_dto: CloneProjectDto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AbstractProjectDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/clone"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = clone_project_dto

        r = self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AbstractProjectDto(**r.json())
        


    def create_custom_fields_on_project(
        self,
        create_custom_field_instances_dto: CreateCustomFieldInstancesDto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> CustomFieldInstancesDto:
        """
        Operation id: createCustomFieldsOnProject
        Create custom field instances
        
        :param create_custom_field_instances_dto: CreateCustomFieldInstancesDto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: CustomFieldInstancesDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/customFields"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = create_custom_field_instances_dto

        r = self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return CustomFieldInstancesDto(**r.json())
        


    def create_project_from_template_v2(
        self,
        create_project_from_template_v2_dto: CreateProjectFromTemplateV2Dto,
        template_uid: str,
        phrase_token: Optional[str] = None,
) -> AbstractProjectDtoV2:
        """
        Operation id: createProjectFromTemplateV2
        Create project from template
        
        :param create_project_from_template_v2_dto: CreateProjectFromTemplateV2Dto (required), body. 
        :param template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AbstractProjectDtoV2
        """
        endpoint = f"/api2/v2/projects/applyTemplate/{template_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = create_project_from_template_v2_dto

        r = self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AbstractProjectDtoV2(**r.json())
        


    def create_project_from_template_v2_async(
        self,
        create_project_from_template_async_v2_dto: CreateProjectFromTemplateAsyncV2Dto,
        template_uid: str,
        phrase_token: Optional[str] = None,
) -> AsyncRequestWrapperV2Dto:
        """
        Operation id: createProjectFromTemplateV2Async
        Create project from template (async)
        
        :param create_project_from_template_async_v2_dto: CreateProjectFromTemplateAsyncV2Dto (required), body. 
        :param template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AsyncRequestWrapperV2Dto
        """
        endpoint = f"/api2/v2/projects/applyTemplate/async/{template_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = create_project_from_template_async_v2_dto

        r = self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AsyncRequestWrapperV2Dto(**r.json())
        


    def create_project_v3(
        self,
        create_project_v3_dto: CreateProjectV3Dto,
        phrase_token: Optional[str] = None,
) -> AbstractProjectDtoV2:
        """
        Operation id: createProjectV3
        Create project
        
        :param create_project_v3_dto: CreateProjectV3Dto (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AbstractProjectDtoV2
        """
        endpoint = f"/api2/v3/projects"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = create_project_v3_dto

        r = self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AbstractProjectDtoV2(**r.json())
        


    def delete_custom_field_of_project(
        self,
        field_instance_uid: str,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: deleteCustomFieldOfProject
        Delete custom field of project
        
        :param field_instance_uid: str (required), path. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/projects/{project_uid}/customFields/{field_instance_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    def delete_project(
        self,
        project_uid: str,
        purge: Optional[bool] = False,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: deleteProject
        Delete project
        
        :param project_uid: str (required), path. 
        :param purge: Optional[bool] = False (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/projects/{project_uid}"
        params = {
            "purge": purge
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    def edit_custom_field_on_project(
        self,
        update_custom_field_instance_dto: UpdateCustomFieldInstanceDto,
        field_instance_uid: str,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> CustomFieldInstanceDto:
        """
        Operation id: editCustomFieldOnProject
        Edit custom field of project
        
        :param update_custom_field_instance_dto: UpdateCustomFieldInstanceDto (required), body. 
        :param field_instance_uid: str (required), path. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: CustomFieldInstanceDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/customFields/{field_instance_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = update_custom_field_instance_dto

        r = self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return CustomFieldInstanceDto(**r.json())
        


    def edit_custom_fields_on_project(
        self,
        update_custom_field_instances_dto: UpdateCustomFieldInstancesDto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> CustomFieldInstancesDto:
        """
        Operation id: editCustomFieldsOnProject
        Edit custom fields of the project (batch)
        
        :param update_custom_field_instances_dto: UpdateCustomFieldInstancesDto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: CustomFieldInstancesDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/customFields"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = update_custom_field_instances_dto

        r = self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return CustomFieldInstancesDto(**r.json())
        


    def edit_import_settings_of_project(
        self,
        file_import_settings_create_dto: FileImportSettingsCreateDto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> FileImportSettingsDto:
        """
        Operation id: editImportSettingsOfProject
        Edit project import settings
        
        :param file_import_settings_create_dto: FileImportSettingsCreateDto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: FileImportSettingsDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/importSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = file_import_settings_create_dto

        r = self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return FileImportSettingsDto(**r.json())
        


    def edit_project_access_settings_v2(
        self,
        edit_project_security_settings_dto_v2: EditProjectSecuritySettingsDtoV2,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> ProjectSecuritySettingsDtoV2:
        """
        Operation id: editProjectAccessSettingsV2
        Edit access and security settings
        
        :param edit_project_security_settings_dto_v2: EditProjectSecuritySettingsDtoV2 (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ProjectSecuritySettingsDtoV2
        """
        endpoint = f"/api2/v2/projects/{project_uid}/accessSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = edit_project_security_settings_dto_v2

        r = self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ProjectSecuritySettingsDtoV2(**r.json())
        


    def edit_project_v2(
        self,
        edit_project_v2_dto: EditProjectV2Dto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> AbstractProjectDtoV2:
        """
        Operation id: editProjectV2
        Edit project
        
        :param edit_project_v2_dto: EditProjectV2Dto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AbstractProjectDtoV2
        """
        endpoint = f"/api2/v2/projects/{project_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = edit_project_v2_dto

        r = self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AbstractProjectDtoV2(**r.json())
        


    def edit_project_v3(
        self,
        edit_project_v3_dto: EditProjectV3Dto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> AbstractProjectDtoV2:
        """
        Operation id: editProjectV3
        Edit project
        
        :param edit_project_v3_dto: EditProjectV3Dto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AbstractProjectDtoV2
        """
        endpoint = f"/api2/v3/projects/{project_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = edit_project_v3_dto

        r = self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AbstractProjectDtoV2(**r.json())
        


    def enabled_quality_checks(
        self,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> EnabledQualityChecksDto:
        """
        Operation id: enabledQualityChecks
        Get QA checks
        Returns enabled quality assurance settings.
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: EnabledQualityChecksDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/qaSettingsChecks"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return EnabledQualityChecksDto(**r.json())
        


    def get_analyse_settings_for_project(
        self,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> AnalyseSettingsDto:
        """
        Operation id: getAnalyseSettingsForProject
        Get analyse settings
        
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AnalyseSettingsDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/analyseSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AnalyseSettingsDto(**r.json())
        


    def get_custom_field_of_project(
        self,
        field_instance_uid: str,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> CustomFieldInstanceDto:
        """
        Operation id: getCustomFieldOfProject
        Get custom field of project
        
        :param field_instance_uid: str (required), path. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: CustomFieldInstanceDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/customFields/{field_instance_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return CustomFieldInstanceDto(**r.json())
        


    def get_custom_fields_page_of_project(
        self,
        project_uid: str,
        created_by: Optional[List[str]] = None,
        modified_by: Optional[List[str]] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 20,
        sort_field: Optional[str] = None,
        sort_trend: Optional[str] = "ASC",
        phrase_token: Optional[str] = None,
) -> PageDtoCustomFieldInstanceDto:
        """
        Operation id: getCustomFieldsPageOfProject
        Get custom fields of project (page)
        
        :param project_uid: str (required), path. 
        :param created_by: Optional[List[str]] = None (optional), query. Filter by webhook creators UIDs.
        :param modified_by: Optional[List[str]] = None (optional), query. Filter by webhook updaters UIDs.
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 20 (optional), query. Page size, accepts values between 1 and 50, default 20.
        :param sort_field: Optional[str] = None (optional), query. Sort by this field.
        :param sort_trend: Optional[str] = "ASC" (optional), query. Sort direction.
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoCustomFieldInstanceDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/customFields"
        params = {
            "pageNumber": page_number,
            "pageSize": page_size,
            "createdBy": created_by,
            "modifiedBy": modified_by,
            "sortField": sort_field,
            "sortTrend": sort_trend
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoCustomFieldInstanceDto(**r.json())
        


    def get_file_naming_settings(
        self,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> FileNamingSettingsDto:
        """
        Operation id: getFileNamingSettings
        Get file naming settings for project
        
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: FileNamingSettingsDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/fileNamingSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return FileNamingSettingsDto(**r.json())
        


    def get_financial_settings(
        self,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> FinancialSettingsDto:
        """
        Operation id: getFinancialSettings
        Get financial settings
        
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: FinancialSettingsDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/financialSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return FinancialSettingsDto(**r.json())
        


    def get_import_settings_for_project(
        self,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> FileImportSettingsDto:
        """
        Operation id: getImportSettingsForProject
        Get projects's default import settings
        
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: FileImportSettingsDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/importSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return FileImportSettingsDto(**r.json())
        


    def get_mt_settings_for_project(
        self,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> MTSettingsPerLanguageListDto:
        """
        Operation id: getMtSettingsForProject
        Get project machine translate settings
        
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: MTSettingsPerLanguageListDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/mtSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return MTSettingsPerLanguageListDto(**r.json())
        


    def get_project(
        self,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> AbstractProjectDto | AdminProjectManagerV2:
        """
        Operation id: getProject
        Get project
        
This API call retrieves information specific to a project.

The level of detail in the response varies based on the user's role. Admins, Project Managers, Vendors, Buyers, and
Linguists receive different responses, detailed below.

- Details about predefined system metadata, such as client, domain, subdomain, cost center, business unit, or status.
Note that [Custom Fields](#operation/getCustomField_1), if added to projects, are not included here and require
retrieval via a dedicated Custom Fields API call. Metadata exposed to Linguists or Vendors might differ from what's
visible to Admins or Project Managers.
- [Workflow Step](https://support.phrase.com/hc/en-us/articles/5709717879324-Workflow-TMS-) information, crucial for
user or vendor assignments through APIs. When projects are created, each workflow step's global ID instantiates into a
project-specific workflow step ID necessary for user assignments. Attempting to assign the global workflow step ID
(found under Settings or via Workflow Step APIs) results in an error, as only the project-specific step can be assigned.
- Progress information indicating the total number of jobs across all workflow steps in the project, alongside the
proportion of completed and overdue jobs.

        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AbstractProjectDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AdminProjectManagerV2(**r.json())
        


    def get_project_access_settings_v2(
        self,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> ProjectSecuritySettingsDtoV2:
        """
        Operation id: getProjectAccessSettingsV2
        Get access and security settings
        
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ProjectSecuritySettingsDtoV2
        """
        endpoint = f"/api2/v2/projects/{project_uid}/accessSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ProjectSecuritySettingsDtoV2(**r.json())
        


    def get_project_assignments(
        self,
        project_uid: str,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        provider_name: Optional[str] = None,
        phrase_token: Optional[str] = None,
) -> PageDtoProviderReference:
        """
        Operation id: getProjectAssignments
        List project providers
        
        :param project_uid: str (required), path. 
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 50 (optional), query. Page size, accepts values between 1 and 50, default 50.
        :param provider_name: Optional[str] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoProviderReference
        """
        endpoint = f"/api2/v1/projects/{project_uid}/providers"
        params = {
            "providerName": provider_name,
            "pageNumber": page_number,
            "pageSize": page_size
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoProviderReference(**r.json())
        


    def get_project_pre_translate_settings_v4(
        self,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> PreTranslateSettingsV4Dto:
        """
        Operation id: getProjectPreTranslateSettingsV4
        Get project pre-translate settings
        
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PreTranslateSettingsV4Dto
        """
        endpoint = f"/api2/v4/projects/{project_uid}/preTranslateSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PreTranslateSettingsV4Dto(**r.json())
        


    def get_project_settings(
        self,
        project_uid: str,
        workflow_level: Optional[int] = 1,
        phrase_token: Optional[str] = None,
) -> LqaSettingsDto:
        """
        Operation id: getProjectSettings
        Get LQA settings
        
        :param project_uid: str (required), path. 
        :param workflow_level: Optional[int] = 1 (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: LqaSettingsDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/lqaSettings"
        params = {
            "workflowLevel": workflow_level
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return LqaSettingsDto(**r.json())
        


    def get_project_term_bases(
        self,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> ProjectTermBaseListDto:
        """
        Operation id: getProjectTermBases
        Get term bases
        
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ProjectTermBaseListDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/termBases"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ProjectTermBaseListDto(**r.json())
        


    def get_project_trans_memories_v3(
        self,
        project_uid: str,
        target_lang: Optional[str] = None,
        wf_step_uid: Optional[str] = None,
        phrase_token: Optional[str] = None,
) -> ProjectTransMemoryListDtoV3:
        """
        Operation id: getProjectTransMemoriesV3
        Get translation memories
        
        :param project_uid: str (required), path. 
        :param target_lang: Optional[str] = None (optional), query. Filter project translation memories by target language.
        :param wf_step_uid: Optional[str] = None (optional), query. Filter project translation memories by workflow step.
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ProjectTransMemoryListDtoV3
        """
        endpoint = f"/api2/v3/projects/{project_uid}/transMemories"
        params = {
            "targetLang": target_lang,
            "wfStepUid": wf_step_uid
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ProjectTransMemoryListDtoV3(**r.json())
        


    def get_project_workflow_steps_v2(
        self,
        project_uid: str,
        with_assigned_jobs: Optional[bool] = False,
        phrase_token: Optional[str] = None,
) -> ProjectWorkflowStepListDtoV2:
        """
        Operation id: getProjectWorkflowStepsV2
        Get workflow steps
        
        :param project_uid: str (required), path. 
        :param with_assigned_jobs: Optional[bool] = False (optional), query. Return only steps containing jobs assigned to the calling linguist..
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ProjectWorkflowStepListDtoV2
        """
        endpoint = f"/api2/v2/projects/{project_uid}/workflowSteps"
        params = {
            "withAssignedJobs": with_assigned_jobs
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ProjectWorkflowStepListDtoV2(**r.json())
        


    def get_quotes_for_project(
        self,
        project_uid: str,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        phrase_token: Optional[str] = None,
) -> PageDtoQuoteDto:
        """
        Operation id: getQuotesForProject
        List quotes
        
        :param project_uid: str (required), path. 
        :param page_number: Optional[int] = 0 (optional), query. 
        :param page_size: Optional[int] = 50 (optional), query. Page size, accepts values between 1 and 50, default 50.
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoQuoteDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/quotes"
        params = {
            "pageNumber": page_number,
            "pageSize": page_size
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoQuoteDto(**r.json())
        


    def list_assigned_projects(
        self,
        user_uid: str,
        due_in_hours: Optional[int] = None,
        filename: Optional[str] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        project_name: Optional[str] = None,
        status: Optional[List[str]] = None,
        target_lang: Optional[List[str]] = None,
        workflow_step_id: Optional[int] = None,
        phrase_token: Optional[str] = None,
) -> PageDtoProjectReference:
        """
        Operation id: listAssignedProjects
        List assigned projects
        List projects in which the user is assigned to at least one job matching the criteria
        :param user_uid: str (required), path. 
        :param due_in_hours: Optional[int] = None (optional), query. Number of hours in which the assigned jobs are due. Use `-1` for jobs that are overdue..
        :param filename: Optional[str] = None (optional), query. 
        :param page_number: Optional[int] = 0 (optional), query. 
        :param page_size: Optional[int] = 50 (optional), query. 
        :param project_name: Optional[str] = None (optional), query. 
        :param status: Optional[List[str]] = None (optional), query. Status of the assigned jobs.
        :param target_lang: Optional[List[str]] = None (optional), query. Target language of the assigned jobs.
        :param workflow_step_id: Optional[int] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoProjectReference
        """
        endpoint = f"/api2/v1/users/{user_uid}/projects"
        params = {
            "status": status,
            "targetLang": target_lang,
            "workflowStepId": workflow_step_id,
            "dueInHours": due_in_hours,
            "filename": filename,
            "projectName": project_name,
            "pageNumber": page_number,
            "pageSize": page_size
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoProjectReference(**r.json())
        


    def list_by_project_v3(
        self,
        project_uid: str,
        name: Optional[str] = None,
        only_owner_org: Optional[bool] = None,
        order: Optional[str] = "desc",
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        sort: Optional[str] = "DATE_CREATED",
        uid: Optional[str] = None,
        phrase_token: Optional[str] = None,
) -> PageDtoAnalyseReference:
        """
        Operation id: listByProjectV3
        List analyses by project
        
        :param project_uid: str (required), path. 
        :param name: Optional[str] = None (optional), query. Name to search by.
        :param only_owner_org: Optional[bool] = None (optional), query. 
        :param order: Optional[str] = "desc" (optional), query. Sorting order.
        :param page_number: Optional[int] = 0 (optional), query. 
        :param page_size: Optional[int] = 50 (optional), query. Page size, accepts values between 1 and 50, default 50.
        :param sort: Optional[str] = "DATE_CREATED" (optional), query. Sorting field.
        :param uid: Optional[str] = None (optional), query. Uid to search by.
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoAnalyseReference
        """
        endpoint = f"/api2/v3/projects/{project_uid}/analyses"
        params = {
            "name": name,
            "uid": uid,
            "pageNumber": page_number,
            "pageSize": page_size,
            "sort": sort,
            "order": order,
            "onlyOwnerOrg": only_owner_org
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoAnalyseReference(**r.json())
        


    def list_projects(
        self,
        archived_only: Optional[bool] = False,
        business_unit_id: Optional[int] = None,
        business_unit_name: Optional[str] = None,
        buyer_id: Optional[int] = None,
        client_id: Optional[int] = None,
        client_name: Optional[str] = None,
        cost_center_id: Optional[int] = None,
        cost_center_name: Optional[str] = None,
        created_in_last_hours: Optional[int] = None,
        domain_id: Optional[int] = None,
        domain_name: Optional[str] = None,
        due_in_hours: Optional[int] = None,
        include_archived: Optional[bool] = False,
        job_status_group: Optional[str] = None,
        job_statuses: Optional[List[str]] = None,
        name: Optional[str] = None,
        name_or_internal_id: Optional[str] = None,
        order: Optional[str] = "ASC",
        owner_id: Optional[int] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        sort: Optional[str] = "ID",
        source_langs: Optional[List[str]] = None,
        statuses: Optional[List[str]] = None,
        sub_domain_id: Optional[int] = None,
        sub_domain_name: Optional[str] = None,
        target_langs: Optional[List[str]] = None,
        phrase_token: Optional[str] = None,
) -> PageDtoAbstractProjectDto:
        """
        Operation id: listProjects
        List projects
        
API call to retrieve a paginated list of projects. Contains a subset of information contained in
[Get project](#operation/getProject) API call.

Utilize the query parameters below to refine the search criteria:

- **name** - The full project name or a portion of it. For instance, using `name=GUI` or `name=02` will find projects
named `GUI02`.
- **clientId** - The client's ID within the system, not interchangeable with its UID.
- **clientName** - The complete or partial name of the client. For example, using `clientName=GUI` or `clientName=02`
will find projects associated with the client `GUI02`.
- **businessUnitId** - The business unit's ID within the system, not interchangeable with its UID.
- **businessUnitName** - The complete or partial name of the business unit. For instance, using `businessUnitName=GUI`
or `businessUnitName=02` will find projects linked to the business unit `GUI02`.
- **statuses** - A list of project statuses. When adding multiple statuses, include each as a dedicated query
parameter, e.g., `statuses=ASSIGNED&statuses=COMPLETED`.
- **domainId** - The domain's ID within the system, not interchangeable with its UID.
- **domainName** - The complete or partial name of the domain. Using `domainName=GUI` or `domainName=02` will find
projects associated with the domain `GUI02`.
- **subDomainId** - The subdomain's ID within the system, not interchangeable with its UID.
- **subDomainName** - The complete or partial name of the subdomain. For example, using `subDomainName=GUI` or
`subDomainName=02` will find projects linked to the subdomain `GUI02`.
- **costCenterId** - The cost center's ID within the system, not interchangeable with its UID.
- **costCenterName** - The complete or partial name of the cost center. For instance, using `costCenterName=GUI` or
`costCenterName=02` will find projects associated with the cost center `GUI02`.
- **dueInHours** - Filter for jobs with due dates less than or equal to the specified number of hours.
- **createdInLastHours** - Filter for jobs created within the specified number of hours.
- **ownerId** - The user ID who owns the project within the system, not interchangeable with its UID.
- **jobStatuses** - A list of statuses for jobs within the projects. Include each status as a dedicated query parameter,
e.g., `jobStatuses=ASSIGNED&jobStatuses=COMPLETED`.
- **jobStatusGroup** - The name of the status group used to filter projects containing at least one job with the
specified status, similar to the status filter in the Projects list for a Linguist user.
- **buyerId** - The Buyer's ID.
- **pageNumber** - Indicates the desired page number (zero-based) to retrieve. The total number of pages is returned in
the `totalPages` field within each response.
- **pageSize** - Indicates the page size, affecting the `totalPages` retrieved in each response and potentially
influencing the number of iterations needed to obtain all projects.
- **nameOrInternalId** - Specify either the project name or Internal ID (the sequence number in the project list
displayed in the UI).
- **includeArchived** - A boolean parameter to include archived projects in the search.
- **archivedOnly** - A boolean search indicating whether only archived projects should be searched.

        :param archived_only: Optional[bool] = False (optional), query. List only archived projects, regardless of `includeArchived`.
        :param business_unit_id: Optional[int] = None (optional), query. 
        :param business_unit_name: Optional[str] = None (optional), query. 
        :param buyer_id: Optional[int] = None (optional), query. 
        :param client_id: Optional[int] = None (optional), query. 
        :param client_name: Optional[str] = None (optional), query. 
        :param cost_center_id: Optional[int] = None (optional), query. 
        :param cost_center_name: Optional[str] = None (optional), query. 
        :param created_in_last_hours: Optional[int] = None (optional), query. 
        :param domain_id: Optional[int] = None (optional), query. 
        :param domain_name: Optional[str] = None (optional), query. 
        :param due_in_hours: Optional[int] = None (optional), query. -1 for projects that are overdue.
        :param include_archived: Optional[bool] = False (optional), query. List also archived projects.
        :param job_status_group: Optional[str] = None (optional), query. Allowed for linguists only.
        :param job_statuses: Optional[List[str]] = None (optional), query. Allowed for linguists only.
        :param name: Optional[str] = None (optional), query. 
        :param name_or_internal_id: Optional[str] = None (optional), query. Name or internal ID of project.
        :param order: Optional[str] = "ASC" (optional), query. 
        :param owner_id: Optional[int] = None (optional), query. 
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 50 (optional), query. Page size, accepts values between 1 and 50, default 50.
        :param sort: Optional[str] = "ID" (optional), query. 
        :param source_langs: Optional[List[str]] = None (optional), query. 
        :param statuses: Optional[List[str]] = None (optional), query. 
        :param sub_domain_id: Optional[int] = None (optional), query. 
        :param sub_domain_name: Optional[str] = None (optional), query. 
        :param target_langs: Optional[List[str]] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoAbstractProjectDto
        """
        endpoint = f"/api2/v1/projects"
        params = {
            "name": name,
            "clientId": client_id,
            "clientName": client_name,
            "businessUnitId": business_unit_id,
            "businessUnitName": business_unit_name,
            "statuses": statuses,
            "targetLangs": target_langs,
            "domainId": domain_id,
            "domainName": domain_name,
            "subDomainId": sub_domain_id,
            "subDomainName": sub_domain_name,
            "costCenterId": cost_center_id,
            "costCenterName": cost_center_name,
            "dueInHours": due_in_hours,
            "createdInLastHours": created_in_last_hours,
            "sourceLangs": source_langs,
            "ownerId": owner_id,
            "jobStatuses": job_statuses,
            "jobStatusGroup": job_status_group,
            "buyerId": buyer_id,
            "pageNumber": page_number,
            "pageSize": page_size,
            "nameOrInternalId": name_or_internal_id,
            "includeArchived": include_archived,
            "archivedOnly": archived_only,
            "sort": sort,
            "order": order
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoAbstractProjectDto(**r.json())
        


    def list_providers_3(
        self,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> ProviderListDtoV2:
        """
        Operation id: listProviders_3
        Get suggested providers
        
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ProviderListDtoV2
        """
        endpoint = f"/api2/v2/projects/{project_uid}/providers/suggest"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ProviderListDtoV2(**r.json())
        


    def patch_project(
        self,
        patch_project_dto: PatchProjectDto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> AbstractProjectDto:
        """
        Operation id: patchProject
        Edit project
        
        :param patch_project_dto: PatchProjectDto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AbstractProjectDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = patch_project_dto

        r = self.client.make_request(
            "PATCH",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AbstractProjectDto(**r.json())
        


    def relevant_term_bases(
        self,
        project_uid: str,
        client_name: Optional[str] = None,
        domain_name: Optional[str] = None,
        name: Optional[str] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        strict_lang_matching: Optional[bool] = False,
        sub_domain_name: Optional[str] = None,
        target_langs: Optional[List[str]] = None,
        phrase_token: Optional[str] = None,
) -> PageDtoTermBaseDto:
        """
        Operation id: relevantTermBases
        List project relevant term bases
        
        :param project_uid: str (required), path. 
        :param client_name: Optional[str] = None (optional), query. 
        :param domain_name: Optional[str] = None (optional), query. 
        :param name: Optional[str] = None (optional), query. 
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 50 (optional), query. Page size, accepts values between 1 and 50, default 50.
        :param strict_lang_matching: Optional[bool] = False (optional), query. 
        :param sub_domain_name: Optional[str] = None (optional), query. 
        :param target_langs: Optional[List[str]] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoTermBaseDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/termBases/relevant"
        params = {
            "name": name,
            "domainName": domain_name,
            "clientName": client_name,
            "subDomainName": sub_domain_name,
            "targetLangs": target_langs,
            "strictLangMatching": strict_lang_matching,
            "pageNumber": page_number,
            "pageSize": page_size
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoTermBaseDto(**r.json())
        


    def relevant_trans_memories_for_project(
        self,
        project_uid: str,
        client_name: Optional[str] = None,
        domain_name: Optional[str] = None,
        name: Optional[str] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        strict_lang_matching: Optional[bool] = False,
        sub_domain_name: Optional[str] = None,
        target_langs: Optional[List[str]] = None,
        phrase_token: Optional[str] = None,
) -> PageDtoTransMemoryDto:
        """
        Operation id: relevantTransMemoriesForProject
        List project relevant translation memories
        
        :param project_uid: str (required), path. 
        :param client_name: Optional[str] = None (optional), query. 
        :param domain_name: Optional[str] = None (optional), query. 
        :param name: Optional[str] = None (optional), query. 
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 50 (optional), query. Page size, accepts values between 1 and 50, default 50.
        :param strict_lang_matching: Optional[bool] = False (optional), query. 
        :param sub_domain_name: Optional[str] = None (optional), query. 
        :param target_langs: Optional[List[str]] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoTransMemoryDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/transMemories/relevant"
        params = {
            "name": name,
            "domainName": domain_name,
            "clientName": client_name,
            "subDomainName": sub_domain_name,
            "targetLangs": target_langs,
            "strictLangMatching": strict_lang_matching,
            "pageNumber": page_number,
            "pageSize": page_size
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoTransMemoryDto(**r.json())
        


    def restore_project(
        self,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: restoreProject
        Restore project
        Restores a project that was previously archived
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/projects/{project_uid}/restore"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "PATCH",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    def search_tm_segment(
        self,
        search_tm_request_dto: SearchTMRequestDto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> SearchResponseListTmDto:
        """
        Operation id: searchTmSegment
        Search translation memory for segment in the project
        Returns at most <i>maxSegments</i>
            records with <i>score >= scoreThreshold</i> and at most <i>maxSubsegments</i> records which are subsegment,
            i.e. the source text is substring of the query text.
        :param search_tm_request_dto: SearchTMRequestDto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: SearchResponseListTmDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/transMemories/searchSegmentInProject"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = search_tm_request_dto

        r = self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return SearchResponseListTmDto(**r.json())
        


    def set_financial_settings(
        self,
        set_financial_settings_dto: SetFinancialSettingsDto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> FinancialSettingsDto:
        """
        Operation id: setFinancialSettings
        Edit financial settings
        
        :param set_financial_settings_dto: SetFinancialSettingsDto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: FinancialSettingsDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/financialSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = set_financial_settings_dto

        r = self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return FinancialSettingsDto(**r.json())
        


    def set_mt_settings_for_project(
        self,
        edit_project_mt_settings_dto: EditProjectMTSettingsDto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> MTSettingsPerLanguageListDto:
        """
        Operation id: setMtSettingsForProject
        Edit machine translate settings
        This will erase all mtSettings per language for project.
        To remove all machine translate settings from project call without a machineTranslateSettings parameter.
        :param edit_project_mt_settings_dto: EditProjectMTSettingsDto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: MTSettingsPerLanguageListDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/mtSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = edit_project_mt_settings_dto

        r = self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return MTSettingsPerLanguageListDto(**r.json())
        


    def set_mt_settings_per_language_for_project(
        self,
        edit_project_mt_sett_per_lang_list_dto: EditProjectMTSettPerLangListDto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> MTSettingsPerLanguageListDto:
        """
        Operation id: setMtSettingsPerLanguageForProject
        Edit machine translate settings per language
        This will erase mtSettings for project
        :param edit_project_mt_sett_per_lang_list_dto: EditProjectMTSettPerLangListDto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: MTSettingsPerLanguageListDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/mtSettingsPerLanguage"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = edit_project_mt_sett_per_lang_list_dto

        r = self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return MTSettingsPerLanguageListDto(**r.json())
        


    def set_project_qa_settings_v2(
        self,
        edit_qa_settings_dto_v2: EditQASettingsDtoV2,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> QASettingsDtoV2:
        """
        Operation id: setProjectQASettingsV2
        Edit quality assurance settings
        
        :param edit_qa_settings_dto_v2: EditQASettingsDtoV2 (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: QASettingsDtoV2
        """
        endpoint = f"/api2/v2/projects/{project_uid}/qaSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = edit_qa_settings_dto_v2

        r = self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return QASettingsDtoV2(**r.json())
        


    def set_project_status(
        self,
        set_project_status_dto: SetProjectStatusDto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: setProjectStatus
        Edit project status
        
        :param set_project_status_dto: SetProjectStatusDto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/projects/{project_uid}/setStatus"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = set_project_status_dto

        r = self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    def set_project_term_bases(
        self,
        set_term_base_dto: SetTermBaseDto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> ProjectTermBaseListDto:
        """
        Operation id: setProjectTermBases
        Edit term bases
        
        :param set_term_base_dto: SetTermBaseDto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ProjectTermBaseListDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/termBases"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = set_term_base_dto

        r = self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ProjectTermBaseListDto(**r.json())
        


    def set_project_trans_memories_v3(
        self,
        set_project_trans_memories_v3_dto: SetProjectTransMemoriesV3Dto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> ProjectTransMemoryListDtoV3:
        """
        Operation id: setProjectTransMemoriesV3
        Edit translation memories
        If user wants to edit “All target languages” or "All workflow steps”, 
                       but there are already varied TM settings for individual languages or steps, 
                       then the user risks to overwrite these individual choices.
        :param set_project_trans_memories_v3_dto: SetProjectTransMemoriesV3Dto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ProjectTransMemoryListDtoV3
        """
        endpoint = f"/api2/v3/projects/{project_uid}/transMemories"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = set_project_trans_memories_v3_dto

        r = self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ProjectTransMemoryListDtoV3(**r.json())
        


    def update_file_naming_settings(
        self,
        file_naming_settings_dto: FileNamingSettingsDto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> FileNamingSettingsDto:
        """
        Operation id: updateFileNamingSettings
        Update file naming settings for project
        
        :param file_naming_settings_dto: FileNamingSettingsDto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: FileNamingSettingsDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/fileNamingSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = file_naming_settings_dto

        r = self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return FileNamingSettingsDto(**r.json())
        


    def update_project_pre_translate_settings_v4(
        self,
        pre_translate_settings_v4_dto: PreTranslateSettingsV4Dto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> PreTranslateSettingsV4Dto:
        """
        Operation id: updateProjectPreTranslateSettingsV4
        Update project pre-translate settings
        
        :param pre_translate_settings_v4_dto: PreTranslateSettingsV4Dto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PreTranslateSettingsV4Dto
        """
        endpoint = f"/api2/v4/projects/{project_uid}/preTranslateSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = pre_translate_settings_v4_dto

        r = self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PreTranslateSettingsV4Dto(**r.json())
        



if __name__ == '__main__':
    print("This module is not intended to be run directly.")


from __future__ import annotations

from datetime import datetime
from typing import TYPE_CHECKING, List, Optional, Union, Any

if TYPE_CHECKING:
    from ..client import SyncPhraseTMSClient

from ..models import (
    PageDtoOrganizationEmailTemplateDto,
    OrganizationEmailTemplateDto
    
)


class EmailTemplateOperations:
    def __init__(self, client: SyncPhraseTMSClient):
        self.client = client


    def get_org_email_template(
        self,
        template_uid: str,
        phrase_token: Optional[str] = None,
) -> OrganizationEmailTemplateDto:
        """
        Operation id: getOrgEmailTemplate
        Get email template
        
        :param template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: OrganizationEmailTemplateDto
        """
        endpoint = f"/api2/v1/emailTemplates/{template_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return OrganizationEmailTemplateDto(**r.json())
        


    def list_org_email_templates(
        self,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        type: Optional[str] = None,
        phrase_token: Optional[str] = None,
) -> PageDtoOrganizationEmailTemplateDto:
        """
        Operation id: listOrgEmailTemplates
        List email templates
        
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 50 (optional), query. Page size, accepts values between 1 and 50, default 50.
        :param type: Optional[str] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoOrganizationEmailTemplateDto
        """
        endpoint = f"/api2/v1/emailTemplates"
        params = {
            "type": type,
            "pageNumber": page_number,
            "pageSize": page_size
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoOrganizationEmailTemplateDto(**r.json())
        



if __name__ == '__main__':
    print("This module is not intended to be run directly.")


from __future__ import annotations

from datetime import datetime
from typing import TYPE_CHECKING, List, Optional, Union, Any

if TYPE_CHECKING:
    from ..client import SyncPhraseTMSClient

from ..models import (
    JobPartReadyReferences,
    SegmentsCountsResponseListDto,
    SegmentListDto
    
)


class SegmentOperations:
    def __init__(self, client: SyncPhraseTMSClient):
        self.client = client


    async def get_segments_count(
        self,
        job_part_ready_references: JobPartReadyReferences,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> SegmentsCountsResponseListDto:
        """
        Operation id: getSegmentsCount
        Get segments count
        
This API provides the current count of segments (progress data).

Every time this API is called, it returns the most up-to-date information. Consequently, these numbers will change
dynamically over time. The data retrieved from this API call is utilized to calculate the progress percentage in the UI.

The call returns the following information:

Counts of characters, words, and segments for each of the locked, confirmed, and completed categories. In this context,
_completed_ is defined as `confirmed` + `locked` - `confirmed and locked`.

The number of added words if the [Update source](https://support.phrase.com/hc/en-us/articles/10825557848220-Job-Tools)
operation has been performed on the job. In this context, added words are defined as the original word count plus the
sum of words added during all subsequent update source operations.

The count of segments where relevant machine translation (MT) was available (machineTranslationRelevantSegmentsCount)
and the number of segments where the MT output was post-edited (machineTranslationPostEditedSegmentsCount).

A breakdown of [Quality assurance](https://support.phrase.com/hc/en-us/articles/5709703799324-Quality-Assurance-QA-TMS-)
results, including the number of segments on which it was performed, the count of warnings found, and the number of
warnings that were ignored.

Additionally, a breakdown of the aforementioned information from the previous
[Workflow step](https://support.phrase.com/hc/en-us/articles/5709717879324-Workflow-TMS-) is also provided.

        :param job_part_ready_references: JobPartReadyReferences (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: SegmentsCountsResponseListDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/jobs/segmentsCount"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = job_part_ready_references

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return SegmentsCountsResponseListDto(**r.json())
        


    async def list_segments(
        self,
        job_uid: str,
        project_uid: str,
        begin_index: Optional[int] = 0,
        end_index: Optional[int] = 0,
        phrase_token: Optional[str] = None,
) -> SegmentListDto:
        """
        Operation id: listSegments
        Get segments
        
        :param job_uid: str (required), path. 
        :param project_uid: str (required), path. 
        :param begin_index: Optional[int] = 0 (optional), query. 
        :param end_index: Optional[int] = 0 (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: SegmentListDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/jobs/{job_uid}/segments"
        params = {
            "beginIndex": begin_index,
            "endIndex": end_index
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return SegmentListDto(**r.json())
        



if __name__ == '__main__':
    print("This module is not intended to be run directly.")


from __future__ import annotations

from datetime import datetime
from typing import TYPE_CHECKING, List, Optional, Union, Any

if TYPE_CHECKING:
    from ..client import SyncPhraseTMSClient

from ..models import (
    PageDtoLqaReportRecipientDto,
    LqaReportLinkDto,
    AssessmentRequestDto,
    AssessmentResultsDto,
    FinishAssessmentsDto,
    LqaReportEmailRequestDto,
    RunAutoLqaDto,
    AssessmentDetailDto,
    AssessmentDetailsDto,
    FinishAssessmentDto,
    AssessmentBasicDto,
    AssessmentResultDto,
    ScoringResultDto
    
)


class LanguageQualityAssessmentOperations:
    def __init__(self, client: SyncPhraseTMSClient):
        self.client = client


    async def discard_assessment_results(
        self,
        assessment_request_dto: AssessmentRequestDto,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: discardAssessmentResults
        Discard multiple finished LQA Assessment results
        
        :param assessment_request_dto: AssessmentRequestDto (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/lqa/assessments/scorings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = assessment_request_dto

        r = await self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def discard_ongoing_assessment(
        self,
        job_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: discardOngoingAssessment
        Discard ongoing LQA Assessment
        
        :param job_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/lqa/assessments/{job_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def discard_ongoing_assessments(
        self,
        assessment_request_dto: AssessmentRequestDto,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: discardOngoingAssessments
        Discard multiple ongoing LQA Assessments
        
        :param assessment_request_dto: AssessmentRequestDto (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/lqa/assessments"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = assessment_request_dto

        r = await self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def download_lqa_reports(
        self,
        job_parts: str,
        phrase_token: Optional[str] = None,
) -> bytes:
        """
        Operation id: downloadLqaReports
        Download LQA Assessment XLSX reports
        Returns a single xlsx report or ZIP archive with multiple reports.
If any given jobPart is not from LQA workflow step, reports from successive workflow steps may be returned
If none were found returns 404 error, otherwise returns those that were found.
        :param job_parts: str (required), query. Comma separated list of JobPart UIDs, between 1 and 100 UIDs .
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: bytes
        """
        endpoint = f"/api2/v1/lqa/assessments/reports"
        params = {
            "jobParts": job_parts
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return r.content
        


    async def finish_assessment(
        self,
        finish_assessment_dto: FinishAssessmentDto,
        job_uid: str,
        phrase_token: Optional[str] = None,
) -> ScoringResultDto:
        """
        Operation id: finishAssessment
        Finish LQA Assessment
        Finishing LQA Assessment will calculate score
        :param finish_assessment_dto: FinishAssessmentDto (required), body. 
        :param job_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ScoringResultDto
        """
        endpoint = f"/api2/v1/lqa/assessments/{job_uid}/scorings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = finish_assessment_dto

        r = await self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ScoringResultDto(**r.json())
        


    async def finish_assessments(
        self,
        finish_assessments_dto: FinishAssessmentsDto,
        phrase_token: Optional[str] = None,
) -> AssessmentResultsDto:
        """
        Operation id: finishAssessments
        Finish multiple LQA Assessments
        Finishing LQA Assessments will calculate scores
        :param finish_assessments_dto: FinishAssessmentsDto (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AssessmentResultsDto
        """
        endpoint = f"/api2/v1/lqa/assessments/scorings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = finish_assessments_dto

        r = await self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AssessmentResultsDto(**r.json())
        


    async def get_assessment(
        self,
        job_uid: str,
        phrase_token: Optional[str] = None,
) -> AssessmentDetailDto:
        """
        Operation id: getAssessment
        Get LQA Assessment
        Returns Assessment status and the results.
If given job is not from LQA workflow step, result from successive workflow steps may be returned
        :param job_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AssessmentDetailDto
        """
        endpoint = f"/api2/v1/lqa/assessments/{job_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AssessmentDetailDto(**r.json())
        


    async def get_assessment_results(
        self,
        assessment_request_dto: AssessmentRequestDto,
        phrase_token: Optional[str] = None,
) -> AssessmentResultDto:
        """
        Operation id: getAssessmentResults
        Get LQA Assessment results
        
        :param assessment_request_dto: AssessmentRequestDto (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AssessmentResultDto
        """
        endpoint = f"/api2/v1/lqa/assessments/results"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = assessment_request_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AssessmentResultDto(**r.json())
        


    async def get_assessments(
        self,
        assessment_request_dto: AssessmentRequestDto,
        phrase_token: Optional[str] = None,
) -> AssessmentDetailsDto:
        """
        Operation id: getAssessments
        Get multiple LQA Assessments
        Returns Assessment results for given jobs.
If any given job is not from LQA workflow step, result from successive workflow steps may be returned
        :param assessment_request_dto: AssessmentRequestDto (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AssessmentDetailsDto
        """
        endpoint = f"/api2/v1/lqa/assessments"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = assessment_request_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AssessmentDetailsDto(**r.json())
        


    async def get_lqa_report_link(
        self,
        job_parts: str,
        phrase_token: Optional[str] = None,
) -> LqaReportLinkDto:
        """
        Operation id: getLqaReportLink
        Get sharable link of LQA reports
        
        :param job_parts: str (required), query. Comma separated list of JobPart UIDs.
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: LqaReportLinkDto
        """
        endpoint = f"/api2/v1/lqa/assessments/reports/link"
        params = {
            "jobParts": job_parts
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return LqaReportLinkDto(**r.json())
        


    async def get_lqa_report_recipients(
        self,
        job_parts: str,
        name_or_email: Optional[str] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        phrase_token: Optional[str] = None,
) -> PageDtoLqaReportRecipientDto:
        """
        Operation id: getLqaReportRecipients
        Get recipients of email with LQA reports
        
        :param job_parts: str (required), query. Comma separated list of JobPart UIDs.
        :param name_or_email: Optional[str] = None (optional), query. 
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 50 (optional), query. Page size, accepts values between 1 and 50, default 50.
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoLqaReportRecipientDto
        """
        endpoint = f"/api2/v1/lqa/assessments/reports/recipients"
        params = {
            "pageNumber": page_number,
            "pageSize": page_size,
            "jobParts": job_parts,
            "nameOrEmail": name_or_email
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoLqaReportRecipientDto(**r.json())
        


    async def run_auto_lqa(
        self,
        run_auto_lqa_dto: RunAutoLqaDto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: runAutoLqa
        Run Auto LQA
        Runs Auto LQA either for job parts listed in `jobParts`
                    or for all job parts in the given `projectWorkflowStep`.
                    Both fields are mutually exclusive. If the project has no steps,
                    then all job parts in the project accessible to the user are used.
        :param run_auto_lqa_dto: RunAutoLqaDto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/projects/{project_uid}/runAutoLqa"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = run_auto_lqa_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def send_lqa_report_email(
        self,
        lqa_report_email_request_dto: LqaReportEmailRequestDto,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: sendLqaReportEmail
        Send email(s) with LQA reports
        
        :param lqa_report_email_request_dto: LqaReportEmailRequestDto (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/lqa/assessments/reports/emails"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = lqa_report_email_request_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def start_assessments(
        self,
        assessment_request_dto: AssessmentRequestDto,
        phrase_token: Optional[str] = None,
) -> AssessmentDetailsDto:
        """
        Operation id: startAssessments
        Start multiple LQA Assessments
        Starts LQA assessments for the given job parts.
                    If any of them have the assessment already started or finished, they are left unchanged.
        :param assessment_request_dto: AssessmentRequestDto (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AssessmentDetailsDto
        """
        endpoint = f"/api2/v1/lqa/assessments"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = assessment_request_dto

        r = await self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AssessmentDetailsDto(**r.json())
        


    async def start_new_assessment(
        self,
        job_uid: str,
        phrase_token: Optional[str] = None,
) -> AssessmentBasicDto:
        """
        Operation id: startNewAssessment
        Start LQA Assessment
        Starts LQA assessment for the given job part.
                    If the assessment has already been started or finished, it's discarded and started fresh.
        :param job_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AssessmentBasicDto
        """
        endpoint = f"/api2/v1/lqa/assessments/{job_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AssessmentBasicDto(**r.json())
        



if __name__ == '__main__':
    print("This module is not intended to be run directly.")


from __future__ import annotations

from datetime import datetime
from typing import TYPE_CHECKING, List, Optional, Union, Any

if TYPE_CHECKING:
    from ..client import SyncPhraseTMSClient

from ..models import (
    QuoteCreateV2Dto,
    EmailQuotesRequestDto,
    EmailQuotesResponseDto,
    QuoteDto,
    QuoteV2Dto
    
)


class QuoteOperations:
    def __init__(self, client: SyncPhraseTMSClient):
        self.client = client


    def create_quote_v2(
        self,
        quote_create_v2_dto: QuoteCreateV2Dto,
        phrase_token: Optional[str] = None,
) -> QuoteV2Dto:
        """
        Operation id: createQuoteV2
        Create quote
        Either WorkflowSettings or Units must be sent for billingUnit "Hour".
        :param quote_create_v2_dto: QuoteCreateV2Dto (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: QuoteV2Dto
        """
        endpoint = f"/api2/v2/quotes"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = quote_create_v2_dto

        r = self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return QuoteV2Dto(**r.json())
        


    def delete_quote(
        self,
        quote_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: deleteQuote
        Delete quote
        
        :param quote_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/quotes/{quote_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    def email_quotes(
        self,
        email_quotes_request_dto: EmailQuotesRequestDto,
        phrase_token: Optional[str] = None,
) -> EmailQuotesResponseDto:
        """
        Operation id: emailQuotes
        Email quotes
        
        :param email_quotes_request_dto: EmailQuotesRequestDto (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: EmailQuotesResponseDto
        """
        endpoint = f"/api2/v1/quotes/email"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = email_quotes_request_dto

        r = self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return EmailQuotesResponseDto(**r.json())
        


    def get_2(
        self,
        quote_uid: str,
        phrase_token: Optional[str] = None,
) -> QuoteDto:
        """
        Operation id: get_2
        Get quote
        
        :param quote_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: QuoteDto
        """
        endpoint = f"/api2/v1/quotes/{quote_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return QuoteDto(**r.json())
        



if __name__ == '__main__':
    print("This module is not intended to be run directly.")


from __future__ import annotations

from datetime import datetime
from typing import TYPE_CHECKING, List, Optional, Union, Any

if TYPE_CHECKING:
    from ..client import SyncPhraseTMSClient

from ..models import (
    PageDtoCustomFileTypeDto,
    CustomFileTypeDto,
    DeleteCustomFileTypeDto,
    UpdateCustomFileTypeDto,
    CreateCustomFileTypeDto
    
)


class CustomFileTypeOperations:
    def __init__(self, client: SyncPhraseTMSClient):
        self.client = client


    def create_custom_file_types(
        self,
        create_custom_file_type_dto: CreateCustomFileTypeDto,
        phrase_token: Optional[str] = None,
) -> CustomFileTypeDto:
        """
        Operation id: createCustomFileTypes
        Create custom file type
        
        :param create_custom_file_type_dto: CreateCustomFileTypeDto (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: CustomFileTypeDto
        """
        endpoint = f"/api2/v1/customFileTypes"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = create_custom_file_type_dto

        r = self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return CustomFileTypeDto(**r.json())
        


    def delete_batch_custom_file_type(
        self,
        delete_custom_file_type_dto: DeleteCustomFileTypeDto,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: deleteBatchCustomFileType
        Delete multiple Custom file type
        
        :param delete_custom_file_type_dto: DeleteCustomFileTypeDto (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/customFileTypes"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = delete_custom_file_type_dto

        r = self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    def delete_custom_file_type(
        self,
        custom_file_type_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: deleteCustomFileType
        Delete Custom file type
        
        :param custom_file_type_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/customFileTypes/{custom_file_type_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    def find_custom_file_type(
        self,
        file_name: Optional[str] = None,
        phrase_token: Optional[str] = None,
) -> CustomFileTypeDto:
        """
        Operation id: findCustomFileType
        Find custom file type
        If no matching custom file type is found it returns status 200 and empty body.
        :param file_name: Optional[str] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: CustomFileTypeDto
        """
        endpoint = f"/api2/v1/customFileTypes/find"
        params = {
            "fileName": file_name
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return CustomFileTypeDto(**r.json())
        


    def get_all_custom_file_type(
        self,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        phrase_token: Optional[str] = None,
) -> PageDtoCustomFileTypeDto:
        """
        Operation id: getAllCustomFileType
        Get All Custom file type
        
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 50 (optional), query. Page size, accepts values between 1 and 50, default 50.
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoCustomFileTypeDto
        """
        endpoint = f"/api2/v1/customFileTypes"
        params = {
            "pageNumber": page_number,
            "pageSize": page_size
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoCustomFileTypeDto(**r.json())
        


    def get_custom_file_type(
        self,
        custom_file_type_uid: str,
        phrase_token: Optional[str] = None,
) -> CustomFileTypeDto:
        """
        Operation id: getCustomFileType
        Get Custom file type
        
        :param custom_file_type_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: CustomFileTypeDto
        """
        endpoint = f"/api2/v1/customFileTypes/{custom_file_type_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return CustomFileTypeDto(**r.json())
        


    def update_custom_file_type(
        self,
        update_custom_file_type_dto: UpdateCustomFileTypeDto,
        custom_file_type_uid: str,
        phrase_token: Optional[str] = None,
) -> CustomFileTypeDto:
        """
        Operation id: updateCustomFileType
        Update Custom file type
        
        :param update_custom_file_type_dto: UpdateCustomFileTypeDto (required), body. 
        :param custom_file_type_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: CustomFileTypeDto
        """
        endpoint = f"/api2/v1/customFileTypes/{custom_file_type_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = update_custom_file_type_dto

        r = self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return CustomFileTypeDto(**r.json())
        



if __name__ == '__main__':
    print("This module is not intended to be run directly.")


from __future__ import annotations

from datetime import datetime
from typing import TYPE_CHECKING, List, Optional, Union, Any

if TYPE_CHECKING:
    from ..client import SyncPhraseTMSClient

from ..models import (
    PageDtoAssignedJobDto,
    UserPasswordEditDto,
    PageDtoString,
    PageDtoLastLoginDto,
    PageDtoUserDto,
    PageDtoWorkflowStepReference,
    AbstractUserEditDto,
    AbstractUserCreateDto,
    PageDtoProjectReference,
    UserDetailsDtoV3,
    UserStatisticsListDto,
    UserDto
    
)


class UserOperations:
    def __init__(self, client: SyncPhraseTMSClient):
        self.client = client


    async def cancel_deletion(
        self,
        user_uid: str,
        phrase_token: Optional[str] = None,
) -> UserDto:
        """
        Operation id: cancelDeletion
        Restore user
        
        :param user_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: UserDto
        """
        endpoint = f"/api2/v1/users/{user_uid}/undelete"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return UserDto(**r.json())
        


    async def create_user_v3(
        self,
        abstract_user_create_dto: AbstractUserCreateDto,
        send_invitation: Optional[bool] = False,
        phrase_token: Optional[str] = None,
) -> UserDetailsDtoV3:
        """
        Operation id: createUserV3
        Create user
        
        :param abstract_user_create_dto: AbstractUserCreateDto (required), body. 
        :param send_invitation: Optional[bool] = False (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: UserDetailsDtoV3
        """
        endpoint = f"/api2/v3/users"
        params = {
            "sendInvitation": send_invitation
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = abstract_user_create_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return UserDetailsDtoV3(**r.json())
        


    async def delete_user(
        self,
        user_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: deleteUser
        Delete user
        
        :param user_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/users/{user_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def disable_two_factor_auth_v3(
        self,
        user_uid: str,
        phrase_token: Optional[str] = None,
) -> UserDetailsDtoV3:
        """
        Operation id: disableTwoFactorAuthV3
        Disable two-factor authentication
        
        :param user_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: UserDetailsDtoV3
        """
        endpoint = f"/api2/v3/users/{user_uid}/disableTwoFactorAuth"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return UserDetailsDtoV3(**r.json())
        


    async def get_list_of_users_filtered(
        self,
        email: Optional[str] = None,
        first_name: Optional[str] = None,
        include_deleted: Optional[bool] = False,
        last_name: Optional[str] = None,
        name: Optional[str] = None,
        name_or_email: Optional[str] = None,
        order: Optional[List[str]] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        role: Optional[List[str]] = None,
        sort: Optional[List[str]] = None,
        user_name: Optional[str] = None,
        phrase_token: Optional[str] = None,
) -> PageDtoUserDto:
        """
        Operation id: getListOfUsersFiltered
        List users
        
        :param email: Optional[str] = None (optional), query. 
        :param first_name: Optional[str] = None (optional), query. Filter for first name, that starts with value.
        :param include_deleted: Optional[bool] = False (optional), query. 
        :param last_name: Optional[str] = None (optional), query. Filter for last name, that starts with value.
        :param name: Optional[str] = None (optional), query. Filter for last name or first name, that starts with value.
        :param name_or_email: Optional[str] = None (optional), query. Filter for last name, first name or email starting with the value.
        :param order: Optional[List[str]] = None (optional), query. 
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 50 (optional), query. Page size, accepts values between 1 and 50, default 50.
        :param role: Optional[List[str]] = None (optional), query. 
        :param sort: Optional[List[str]] = None (optional), query. 
        :param user_name: Optional[str] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoUserDto
        """
        endpoint = f"/api2/v1/users"
        params = {
            "firstName": first_name,
            "lastName": last_name,
            "name": name,
            "userName": user_name,
            "email": email,
            "nameOrEmail": name_or_email,
            "role": role,
            "includeDeleted": include_deleted,
            "pageNumber": page_number,
            "pageSize": page_size,
            "sort": sort,
            "order": order
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoUserDto(**r.json())
        


    async def get_user_v3(
        self,
        user_uid: str,
        phrase_token: Optional[str] = None,
) -> UserDetailsDtoV3:
        """
        Operation id: getUserV3
        Get user
        
        :param user_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: UserDetailsDtoV3
        """
        endpoint = f"/api2/v3/users/{user_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return UserDetailsDtoV3(**r.json())
        


    async def list_assigned_projects(
        self,
        user_uid: str,
        due_in_hours: Optional[int] = None,
        filename: Optional[str] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        project_name: Optional[str] = None,
        status: Optional[List[str]] = None,
        target_lang: Optional[List[str]] = None,
        workflow_step_id: Optional[int] = None,
        phrase_token: Optional[str] = None,
) -> PageDtoProjectReference:
        """
        Operation id: listAssignedProjects
        List assigned projects
        List projects in which the user is assigned to at least one job matching the criteria
        :param user_uid: str (required), path. 
        :param due_in_hours: Optional[int] = None (optional), query. Number of hours in which the assigned jobs are due. Use `-1` for jobs that are overdue..
        :param filename: Optional[str] = None (optional), query. 
        :param page_number: Optional[int] = 0 (optional), query. 
        :param page_size: Optional[int] = 50 (optional), query. 
        :param project_name: Optional[str] = None (optional), query. 
        :param status: Optional[List[str]] = None (optional), query. Status of the assigned jobs.
        :param target_lang: Optional[List[str]] = None (optional), query. Target language of the assigned jobs.
        :param workflow_step_id: Optional[int] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoProjectReference
        """
        endpoint = f"/api2/v1/users/{user_uid}/projects"
        params = {
            "status": status,
            "targetLang": target_lang,
            "workflowStepId": workflow_step_id,
            "dueInHours": due_in_hours,
            "filename": filename,
            "projectName": project_name,
            "pageNumber": page_number,
            "pageSize": page_size
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoProjectReference(**r.json())
        


    async def list_jobs(
        self,
        user_uid: str,
        due_in_hours: Optional[int] = None,
        filename: Optional[str] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        project_uid: Optional[str] = None,
        status: Optional[List[str]] = None,
        target_lang: Optional[List[str]] = None,
        workflow_step_id: Optional[int] = None,
        phrase_token: Optional[str] = None,
) -> PageDtoAssignedJobDto:
        """
        Operation id: listJobs
        List assigned jobs
        
        :param user_uid: str (required), path. 
        :param due_in_hours: Optional[int] = None (optional), query. -1 for jobs that are overdue.
        :param filename: Optional[str] = None (optional), query. 
        :param page_number: Optional[int] = 0 (optional), query. 
        :param page_size: Optional[int] = 50 (optional), query. 
        :param project_uid: Optional[str] = None (optional), query. 
        :param status: Optional[List[str]] = None (optional), query. 
        :param target_lang: Optional[List[str]] = None (optional), query. 
        :param workflow_step_id: Optional[int] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoAssignedJobDto
        """
        endpoint = f"/api2/v1/users/{user_uid}/jobs"
        params = {
            "status": status,
            "projectUid": project_uid,
            "targetLang": target_lang,
            "workflowStepId": workflow_step_id,
            "dueInHours": due_in_hours,
            "filename": filename,
            "pageNumber": page_number,
            "pageSize": page_size
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoAssignedJobDto(**r.json())
        


    async def list_target_langs(
        self,
        user_uid: str,
        due_in_hours: Optional[int] = None,
        filename: Optional[str] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        project_uid: Optional[str] = None,
        status: Optional[List[str]] = None,
        workflow_step_id: Optional[int] = None,
        phrase_token: Optional[str] = None,
) -> PageDtoString:
        """
        Operation id: listTargetLangs
        List assigned target languages
        
        :param user_uid: str (required), path. 
        :param due_in_hours: Optional[int] = None (optional), query. -1 for jobs that are overdue.
        :param filename: Optional[str] = None (optional), query. 
        :param page_number: Optional[int] = 0 (optional), query. 
        :param page_size: Optional[int] = 50 (optional), query. 
        :param project_uid: Optional[str] = None (optional), query. 
        :param status: Optional[List[str]] = None (optional), query. 
        :param workflow_step_id: Optional[int] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoString
        """
        endpoint = f"/api2/v1/users/{user_uid}/targetLangs"
        params = {
            "status": status,
            "projectUid": project_uid,
            "workflowStepId": workflow_step_id,
            "dueInHours": due_in_hours,
            "filename": filename,
            "pageNumber": page_number,
            "pageSize": page_size
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoString(**r.json())
        


    async def list_workflow_steps(
        self,
        user_uid: str,
        due_in_hours: Optional[int] = None,
        filename: Optional[str] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        project_uid: Optional[str] = None,
        status: Optional[List[str]] = None,
        target_lang: Optional[List[str]] = None,
        phrase_token: Optional[str] = None,
) -> PageDtoWorkflowStepReference:
        """
        Operation id: listWorkflowSteps
        List assigned workflow steps
        
        :param user_uid: str (required), path. 
        :param due_in_hours: Optional[int] = None (optional), query. -1 for jobs that are overdue.
        :param filename: Optional[str] = None (optional), query. 
        :param page_number: Optional[int] = 0 (optional), query. 
        :param page_size: Optional[int] = 50 (optional), query. 
        :param project_uid: Optional[str] = None (optional), query. 
        :param status: Optional[List[str]] = None (optional), query. 
        :param target_lang: Optional[List[str]] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoWorkflowStepReference
        """
        endpoint = f"/api2/v1/users/{user_uid}/workflowSteps"
        params = {
            "status": status,
            "projectUid": project_uid,
            "targetLang": target_lang,
            "dueInHours": due_in_hours,
            "filename": filename,
            "pageNumber": page_number,
            "pageSize": page_size
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoWorkflowStepReference(**r.json())
        


    async def login_activity(
        self,
        user_uid: str,
        phrase_token: Optional[str] = None,
) -> UserStatisticsListDto:
        """
        Operation id: loginActivity
        Login statistics
        
        :param user_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: UserStatisticsListDto
        """
        endpoint = f"/api2/v1/users/{user_uid}/loginStatistics"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return UserStatisticsListDto(**r.json())
        


    async def send_login_info(
        self,
        user_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: sendLoginInfo
        Send login information
        
        :param user_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/users/{user_uid}/emailLoginInformation"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def update_password(
        self,
        user_password_edit_dto: UserPasswordEditDto,
        user_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: updatePassword
        Update password
        
Can be used by the user to update their own password or by ADMIN to update password of user without joined account
* Password length must be between 8 and 255
* Password must not be same as the username

        :param user_password_edit_dto: UserPasswordEditDto (required), body. 
        :param user_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/users/{user_uid}/updatePassword"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = user_password_edit_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def update_user_v3(
        self,
        abstract_user_edit_dto: AbstractUserEditDto,
        user_uid: str,
        phrase_token: Optional[str] = None,
) -> UserDetailsDtoV3:
        """
        Operation id: updateUserV3
        Edit user
        
        :param abstract_user_edit_dto: AbstractUserEditDto (required), body. 
        :param user_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: UserDetailsDtoV3
        """
        endpoint = f"/api2/v3/users/{user_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = abstract_user_edit_dto

        r = await self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return UserDetailsDtoV3(**r.json())
        


    async def user_last_logins(
        self,
        order: Optional[List[str]] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 100,
        role: Optional[List[str]] = None,
        sort: Optional[List[str]] = None,
        user_name: Optional[str] = None,
        phrase_token: Optional[str] = None,
) -> PageDtoLastLoginDto:
        """
        Operation id: user-lastLogins
        List last login dates
        
        :param order: Optional[List[str]] = None (optional), query. 
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 100 (optional), query. Page size, accepts values between 1 and 100, default 100.
        :param role: Optional[List[str]] = None (optional), query. 
        :param sort: Optional[List[str]] = None (optional), query. 
        :param user_name: Optional[str] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoLastLoginDto
        """
        endpoint = f"/api2/v1/users/lastLogins"
        params = {
            "userName": user_name,
            "role": role,
            "sort": sort,
            "order": order,
            "pageNumber": page_number,
            "pageSize": page_size
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoLastLoginDto(**r.json())
        



if __name__ == '__main__':
    print("This module is not intended to be run directly.")


from __future__ import annotations

from datetime import datetime
from typing import TYPE_CHECKING, List, Optional, Union, Any

if TYPE_CHECKING:
    from ..client import SyncPhraseTMSClient

from ..models import (
    MachineTranslateResponse,
    TranslationRequestExtendedDto
    
)


class MachineTranslationOperations:
    def __init__(self, client: SyncPhraseTMSClient):
        self.client = client


    async def machine_translation(
        self,
        translation_request_extended_dto: TranslationRequestExtendedDto,
        mt_settings_uid: str,
        phrase_token: Optional[str] = None,
) -> MachineTranslateResponse:
        """
        Operation id: machineTranslation
        Translate with MT
        
        :param translation_request_extended_dto: TranslationRequestExtendedDto (required), body. 
        :param mt_settings_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: MachineTranslateResponse
        """
        endpoint = f"/api2/v1/machineTranslations/{mt_settings_uid}/translate"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = translation_request_extended_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return MachineTranslateResponse(**r.json())
        



if __name__ == '__main__':
    print("This module is not intended to be run directly.")


from typing import List, Optional

from pydantic import BaseModel, Field

from .phrase_tms_api_models import UidReference


class UpdateCustomFieldDto(BaseModel):
    name: str = Field(min_length=0, max_length=255)
    allowedEntities: List[str]
    required: Optional[bool] = None
    description: Optional[str] = Field(min_length=0, max_length=500)
    addOptions: Optional[List[str]] = None
    removeOptions: Optional[List[UidReference]] = None


from __future__ import annotations

from datetime import datetime
from typing import TYPE_CHECKING, List, Optional, Union, Any

if TYPE_CHECKING:
    from ..client import SyncPhraseTMSClient

from ..models import (
    LQAConversationDto,
    PageDtoCommonConversationDto,
    CreateLqaConversationDto,
    LQAConversationsListDto,
    FindConversationsDto,
    EditPlainConversationDto,
    ConversationListDto,
    AddCommentDto,
    AddPlainCommentResultDto,
    FindConversationsForProjectDto,
    PlainConversationsListDto,
    CreatePlainConversationDto,
    EditLqaConversationDto,
    AddLqaCommentResultDto,
    PlainConversationDto
    
)


class ConversationsOperations:
    def __init__(self, client: SyncPhraseTMSClient):
        self.client = client


    async def add_lqa_comment_v2(
        self,
        add_comment_dto: AddCommentDto,
        conversation_id: str,
        job_uid: str,
        phrase_token: Optional[str] = None,
) -> AddLqaCommentResultDto:
        """
        Operation id: addLQACommentV2
        Add LQA comment
        
        :param add_comment_dto: AddCommentDto (required), body. 
        :param conversation_id: str (required), path. 
        :param job_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AddLqaCommentResultDto
        """
        endpoint = f"/api2/v2/jobs/{job_uid}/conversations/lqas/{conversation_id}/comments"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = add_comment_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AddLqaCommentResultDto(**r.json())
        


    async def add_plain_comment_v3(
        self,
        add_comment_dto: AddCommentDto,
        conversation_id: str,
        job_uid: str,
        phrase_token: Optional[str] = None,
) -> AddPlainCommentResultDto:
        """
        Operation id: addPlainCommentV3
        Add plain comment
        
        :param add_comment_dto: AddCommentDto (required), body. 
        :param conversation_id: str (required), path. 
        :param job_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AddPlainCommentResultDto
        """
        endpoint = f"/api2/v3/jobs/{job_uid}/conversations/plains/{conversation_id}/comments"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = add_comment_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AddPlainCommentResultDto(**r.json())
        


    async def create_lqa_conversation_v2(
        self,
        create_lqa_conversation_dto: CreateLqaConversationDto,
        job_uid: str,
        phrase_token: Optional[str] = None,
) -> LQAConversationDto:
        """
        Operation id: createLqaConversationV2
        Create LQA conversation
        
        :param create_lqa_conversation_dto: CreateLqaConversationDto (required), body. 
        :param job_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: LQAConversationDto
        """
        endpoint = f"/api2/v2/jobs/{job_uid}/conversations/lqas"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = create_lqa_conversation_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return LQAConversationDto(**r.json())
        


    async def create_segment_target_conversation_v3(
        self,
        create_plain_conversation_dto: CreatePlainConversationDto,
        job_uid: str,
        phrase_token: Optional[str] = None,
) -> PlainConversationDto:
        """
        Operation id: createSegmentTargetConversationV3
        Create plain conversation
        
        :param create_plain_conversation_dto: CreatePlainConversationDto (required), body. 
        :param job_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PlainConversationDto
        """
        endpoint = f"/api2/v3/jobs/{job_uid}/conversations/plains"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = create_plain_conversation_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PlainConversationDto(**r.json())
        


    async def delete_lqa_comment(
        self,
        comment_id: str,
        conversation_id: str,
        job_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: deleteLQAComment
        Delete LQA comment
        
        :param comment_id: str (required), path. 
        :param conversation_id: str (required), path. 
        :param job_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/jobs/{job_uid}/conversations/lqas/{conversation_id}/comments/{comment_id}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def delete_lqa_conversation(
        self,
        conversation_id: str,
        job_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: deleteLQAConversation
        Delete LQA conversation
        
        :param conversation_id: str (required), path. 
        :param job_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/jobs/{job_uid}/conversations/lqas/{conversation_id}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def delete_plain_comment(
        self,
        comment_id: str,
        conversation_id: str,
        job_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: deletePlainComment
        Delete plain comment
        
        :param comment_id: str (required), path. 
        :param conversation_id: str (required), path. 
        :param job_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/jobs/{job_uid}/conversations/plains/{conversation_id}/comments/{comment_id}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def delete_plain_conversation(
        self,
        conversation_id: str,
        job_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: deletePlainConversation
        Delete plain conversation
        
        :param conversation_id: str (required), path. 
        :param job_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/jobs/{job_uid}/conversations/plains/{conversation_id}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def find_conversations(
        self,
        find_conversations_dto: FindConversationsDto,
        phrase_token: Optional[str] = None,
) -> ConversationListDto:
        """
        Operation id: findConversations
        Find all conversation
        
        :param find_conversations_dto: FindConversationsDto (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ConversationListDto
        """
        endpoint = f"/api2/v1/jobs/conversations/find"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = find_conversations_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ConversationListDto(**r.json())
        


    async def get_lqa_conversation(
        self,
        conversation_id: str,
        job_uid: str,
        phrase_token: Optional[str] = None,
) -> LQAConversationDto:
        """
        Operation id: getLQAConversation
        Get LQA conversation
        
        :param conversation_id: str (required), path. 
        :param job_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: LQAConversationDto
        """
        endpoint = f"/api2/v1/jobs/{job_uid}/conversations/lqas/{conversation_id}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return LQAConversationDto(**r.json())
        


    async def get_plain_conversation(
        self,
        conversation_id: str,
        job_uid: str,
        phrase_token: Optional[str] = None,
) -> PlainConversationDto:
        """
        Operation id: getPlainConversation
        Get plain conversation
        
        :param conversation_id: str (required), path. 
        :param job_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PlainConversationDto
        """
        endpoint = f"/api2/v1/jobs/{job_uid}/conversations/plains/{conversation_id}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PlainConversationDto(**r.json())
        


    async def list_all_conversations(
        self,
        job_uid: str,
        include_deleted: Optional[bool] = False,
        since: Optional[str] = None,
        phrase_token: Optional[str] = None,
) -> ConversationListDto:
        """
        Operation id: listAllConversations
        List all conversations
        
        :param job_uid: str (required), path. 
        :param include_deleted: Optional[bool] = False (optional), query. 
        :param since: Optional[str] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ConversationListDto
        """
        endpoint = f"/api2/v1/jobs/{job_uid}/conversations"
        params = {
            "includeDeleted": include_deleted,
            "since": since
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ConversationListDto(**r.json())
        


    async def list_lqa_conversations(
        self,
        job_uid: str,
        include_deleted: Optional[bool] = False,
        since: Optional[str] = None,
        phrase_token: Optional[str] = None,
) -> LQAConversationsListDto:
        """
        Operation id: listLQAConversations
        List LQA conversations
        
        :param job_uid: str (required), path. 
        :param include_deleted: Optional[bool] = False (optional), query. 
        :param since: Optional[str] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: LQAConversationsListDto
        """
        endpoint = f"/api2/v1/jobs/{job_uid}/conversations/lqas"
        params = {
            "includeDeleted": include_deleted,
            "since": since
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return LQAConversationsListDto(**r.json())
        


    async def list_plain_conversations(
        self,
        job_uid: str,
        include_deleted: Optional[bool] = False,
        since: Optional[str] = None,
        phrase_token: Optional[str] = None,
) -> PlainConversationsListDto:
        """
        Operation id: listPlainConversations
        List plain conversations
        
        :param job_uid: str (required), path. 
        :param include_deleted: Optional[bool] = False (optional), query. 
        :param since: Optional[str] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PlainConversationsListDto
        """
        endpoint = f"/api2/v1/jobs/{job_uid}/conversations/plains"
        params = {
            "includeDeleted": include_deleted,
            "since": since
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PlainConversationsListDto(**r.json())
        


    async def search_by_project(
        self,
        find_conversations_for_project_dto: FindConversationsForProjectDto,
        phrase_token: Optional[str] = None,
) -> PageDtoCommonConversationDto:
        """
        Operation id: searchByProject
        Search conversation by project
        This endpoint is allowed only to PM and ADMIN roles.
        :param find_conversations_for_project_dto: FindConversationsForProjectDto (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoCommonConversationDto
        """
        endpoint = f"/api2/v1/jobs/conversations/searchByProject"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = find_conversations_for_project_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoCommonConversationDto(**r.json())
        


    async def update_lqa_comment_v2(
        self,
        add_comment_dto: AddCommentDto,
        comment_id: str,
        conversation_id: str,
        job_uid: str,
        phrase_token: Optional[str] = None,
) -> LQAConversationDto:
        """
        Operation id: updateLQACommentV2
        Edit LQA comment
        
        :param add_comment_dto: AddCommentDto (required), body. 
        :param comment_id: str (required), path. 
        :param conversation_id: str (required), path. 
        :param job_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: LQAConversationDto
        """
        endpoint = f"/api2/v2/jobs/{job_uid}/conversations/lqas/{conversation_id}/comments/{comment_id}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = add_comment_dto

        r = await self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return LQAConversationDto(**r.json())
        


    async def update_lqa_conversation_v2(
        self,
        edit_lqa_conversation_dto: EditLqaConversationDto,
        conversation_id: str,
        job_uid: str,
        phrase_token: Optional[str] = None,
) -> LQAConversationDto:
        """
        Operation id: updateLqaConversationV2
        Update LQA conversation
        
        :param edit_lqa_conversation_dto: EditLqaConversationDto (required), body. 
        :param conversation_id: str (required), path. 
        :param job_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: LQAConversationDto
        """
        endpoint = f"/api2/v2/jobs/{job_uid}/conversations/lqas/{conversation_id}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = edit_lqa_conversation_dto

        r = await self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return LQAConversationDto(**r.json())
        


    async def update_plain_comment_v3(
        self,
        add_comment_dto: AddCommentDto,
        comment_id: str,
        conversation_id: str,
        job_uid: str,
        phrase_token: Optional[str] = None,
) -> PlainConversationDto:
        """
        Operation id: updatePlainCommentV3
        Edit plain comment
        
        :param add_comment_dto: AddCommentDto (required), body. 
        :param comment_id: str (required), path. 
        :param conversation_id: str (required), path. 
        :param job_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PlainConversationDto
        """
        endpoint = f"/api2/v3/jobs/{job_uid}/conversations/plains/{conversation_id}/comments/{comment_id}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = add_comment_dto

        r = await self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PlainConversationDto(**r.json())
        


    async def update_plain_conversation(
        self,
        edit_plain_conversation_dto: EditPlainConversationDto,
        conversation_id: str,
        job_uid: str,
        phrase_token: Optional[str] = None,
) -> PlainConversationDto:
        """
        Operation id: updatePlainConversation
        Edit plain conversation
        
        :param edit_plain_conversation_dto: EditPlainConversationDto (required), body. 
        :param conversation_id: str (required), path. 
        :param job_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PlainConversationDto
        """
        endpoint = f"/api2/v1/jobs/{job_uid}/conversations/plains/{conversation_id}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = edit_plain_conversation_dto

        r = await self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PlainConversationDto(**r.json())
        



if __name__ == '__main__':
    print("This module is not intended to be run directly.")